# Junctions
Layered junctioning for Rails. Feature flags done right.

Junctions works by enabling conditional namespaced module inclusion. What that actually means is that features
in a module can be enabled or disable by creating them in a particular namespace. For example:

```ruby
module Core
  module Extensions
    include Junctions
    def overridden_method
      puts('You are in core')
    end
  end 
end

module Wibble
  module Extensions
    def overridden_method
      puts('Wibble')
    end
  end
end

module Wobble
  module Extensions
    def overridden_method
      puts('Something else')
    end
  end
end

class Demon
  include Core::Extensions
end

```
Including Junctions in Core means that if there is a 'junctions' setting as, for example, an environment variable
```bash
  junctions=wibble, wobble
```
would first load up Core, then Wibble and finally Wobble as modules and include each of them in turn. This has the effect of
overriding the 'overridden_method' inside Core to display 'Something else' as the message.
Likewise if the environment variable were:
```bash
  junctions=wibble
```
This would only include Wibble into the list of namespaces to override Core methods.

You can also perform this override within the code entirely. Passing it in as an environment variable is the preferred
way to handle it, but there are other options since the Junctions core and junction_list setter functions are exposed
```ruby 
Junctions::Engine.core = 'common'
Junctions::Engine.junction_list = ['wibble', 'wobble']
```

#Ruby and Rails Versions

Junctions is built for Ruby 2.4+ and Rails 5+.

